@@ -1,3 +1,4 @@
+from crispy_forms.helper import FormHelper
 from django.forms import BaseModelFormSet, BooleanField, ModelForm, modelformset_factory
 from django.forms.formsets import DELETION_FIELD_NAME
 from django.utils.translation import gettext as _
@@ -17,6 +18,8 @@ class ResourceAllocationForm(BasePluginFormMixin, ModelForm):
 
     def __init__(self, *args, shift, **kwargs):
         self.shift = shift
+        self.helper = FormHelper()
+        self.helper.include_media = False
         try:
             kwargs.setdefault("instance", ResourceAllocation.objects.get(shift=shift))
         except ResourceAllocation.DoesNotExist:
@@ -56,5 +59,5 @@ ResourceCategoryFormset = modelformset_factory(
     formset=BaseResourceCategoryFormset,
     can_delete=True,
     extra=0,
-    fields=["name"],
+    fields=["name", "icon"],
 )
