@@ -1,10 +1,12 @@
 from django.db import models
+from django.utils.translation import gettext_lazy as _
 
 from ephios.core.models import Shift
 
 
 class ResourceCategory(models.Model):
-    name = models.CharField(max_length=50)
+    name = models.CharField(max_length=50, verbose_name=_("Name"))
+    icon = models.CharField(max_length=50, default="box", help_text="FontAwesome icon name")
 
     def __str__(self):
         # pylint: disable=invalid-str-returned
@@ -12,8 +14,10 @@ class ResourceCategory(models.Model):
 
 
 class Resource(models.Model):
-    title = models.CharField(max_length=100)
-    category = models.ForeignKey(ResourceCategory, on_delete=models.CASCADE)
+    title = models.CharField(max_length=100, verbose_name=_("Title"))
+    category = models.ForeignKey(
+        ResourceCategory, on_delete=models.CASCADE, verbose_name=_("Category")
+    )
 
     def __str__(self):
         # pylint: disable=invalid-str-returned
@@ -22,7 +26,7 @@ class Resource(models.Model):
 
 class ResourceAllocation(models.Model):
     shift = models.ForeignKey(Shift, on_delete=models.CASCADE)
-    resources = models.ManyToManyField(Resource, blank=True)
+    resources = models.ManyToManyField(Resource, blank=True, verbose_name=_("Resources"))
 
     def __str__(self):
         return f"Resource allocation for {self.shift}"
